@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 module Database.HDBC.Locale
     (
      defaultTimeLocale,
@@ -5,7 +6,12 @@ module Database.HDBC.Locale
     )
 
 where
+
+#ifdef MIN_TIME_15
+import Data.Time.Format (defaultTimeLocale)
+#else
 import System.Locale (defaultTimeLocale)
+#endif
 
 -- | As the semantic of System.Locale.iso8601DateFormat has changed with
 --   old-locale-1.0.0.2 in a non-compatible way, we now define our own
